;; Generated package description from termint.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "termint" "0.2.2" "Run REPLs in a terminal backend" '((emacs "29.1")) :commit "689549245bb6dc0429d8af06c4830c92b09f4667" :authors '(("Milan Glacier" . "dev@milanglacier.com")) :maintainer '("Milan Glacier" . "dev@milanglacier.com") :url "https://github.com/milanglacier/termint.el")
